@@ -8,7 +8,7 @@ from .enums import ComponentType
 from .tools import deprecated
 
 import discord
-from discord.errors import InvalidArgument
+from discord import InvalidArgument
 from discord.ext.commands import Cog, CheckFailure, CooldownMapping, BucketType, CommandOnCooldown
 
 import inspect
